# Installation "pip install mysqlclient"
# Document https://mysqlclient.readthedocs.io/
import MySQLdb 

class EasyDB :
    def __init__(self, conf):
        # Connect with parameters
        try :
            self.__dbconn = MySQLdb.connect( \
            host=conf[0], user=conf[1], passwd=conf[2], db=conf[3], charset='utf8')
            self.__error = ""
        except MySQLdb.Error as e :
            self.__error = "{} {}".format(type(e), e)
    
    @property
    def error(self) :
        # Report errors
        return self.__error
    
    @property
    def rowcount(self) :
        # Return the number of affected rows
        return self.__rowcount

    def fetchall(self, sql) :
        try :
            # Set cursor
            cursor = self.__dbconn.cursor()
            cursor.execute(sql)
            # Fetch all
            tuples = cursor.fetchall()
            self.__rowcount = cursor.rowcount
            self.__error = ""
            # Convert tuple to list
            thelist = list()
            for atuple in tuples:
                row = list(atuple)
                thelist.append(row)
            if thelist == None : return ""    
            return thelist
        except MySQLdb.Error as e :
            self.__error = "{} {}".format(type(e), e)

    def fetchone(self, sql) :
        try :
            # Set cursor
            cursor = self.__dbconn.cursor()
            cursor.execute(sql)
            # Fetch one and convert tuple to list
            atuple = cursor.fetchone()
            self.__rowcount = cursor.rowcount
            self.__error = ""
            if atuple == None : return ""
            return list(atuple)      
        except MySQLdb.Error as e :
            self.__error = "{} {}".format(type(e), e)

    def execute(self, sql) :
        try :
            # Set cursor
            cursor = self.__dbconn.cursor()
            cursor.execute(sql)
            # Commit
            self.__dbconn.commit()
            self.__rowcount = cursor.rowcount
            self.__error = ""
        except MySQLdb.Error as e :
            self.__error = "{} {}".format(type(e), e)
